Installation
------------

To install you can use pypi:

.. code-block:: bash

   $ pip install pys3landsat

or if you want to build and install from source:


.. code-block:: bash

   $ git clone https://github.com/eamanu/pyamazonlandsat.git
   $ python setup.py build
   $ python setup.py install

